#!/usr/bin/perl
use strict;
#use Test::More tests => 1;

BEGIN {
  if(!defined($ENV{LS_COLORS}) or ($ENV{LS_COLORS} eq '')) {
    $File::LsColor::LS_COLORS}='pl=38;5;220:pm=38;5;196';
  }
  use Test::More test => 1;
  use_ok('File::LsColor');
}

